==> easyleetcode-1.6.0.tar.gz: easyleetcode-1.6.0/easyleetcode/web/server.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : server.py
import os
from fastapi import APIRouter

from fastapi import Request
from easyleetcode.config import templates
import easyleetcode.web.code_util as code_util
from easyleetcode.web.Items import Item
import easyleetcode.web.utils as utils
import easyleetcode.config as config

router = APIRouter()

python_path = 'python '


@router.get('/')
async def index(request: Request):
    return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Leetcode'})


@router.get('/help')
async def help(request: Request):
    return templates.TemplateResponse("help.html", {"request": request, "message": 'Easy Leetcode'})


@router.get('/about')
async def about(request: Request):
    return templates.TemplateResponse("about.html", {"request": request, "message": 'Easy Leetcode'})


code_map, code_name_map, code_name_list = utils.load_data()


def remove_name(name):
    global code_name_map, code_map, code_name_list
    kid = code_name_map[name][0]
    del code_name_map[name]
    del code_map[kid]
    ci = None
    for ci in code_name_list:
        if ci[1] == name:
            break
    if ci is not None:
        code_name_list.remove(ci)


@router.get('/view')
async def view(request: Request):
    count_day = utils.get_file_txt_count(config.count_day)
    count_view_code = utils.get_file_txt_count(config.count_view_code)
    data = {
        'all_num': len(code_name_list),
        'count_day': count_day,
        'count_view_code': count_view_code,
        'code_name_list': code_name_list
    }
    return templates.TemplateResponse("code_list.html", {"request": request, "data": data, "message": "Leetcode List"})


@router.get('/filter_view/{keyword}')
async def view(request: Request, keyword: str = 'L'):
    count_day = utils.get_file_txt_count(config.count_day)
    count_view_code = utils.get_file_txt_count(config.count_view_code)
    f_code_name_list = [ni for ni in code_name_list if keyword in ni[2]]
    data = {
        'all_num': len(code_name_list),
        'count_day': count_day,
        'count_view_code': count_view_code,
        'code_name_list': f_code_name_list
    }
    return templates.TemplateResponse("code_list.html", {"request": request, "data": data, "message": "Leetcode List"})


@router.get('/code/{name}')
async def view_code(request: Request, name: str = '001_Two_Sum'):
    global code_name_map, code_map, code_name_list
    if name not in code_name_map:
        return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Leetcode'})
    # 代码路径
    code_path = code_name_map[name][1]
    # 代码markdwon路径
    code_md_path = code_name_map[name][2]
    code_str = code_util.get_file_read(code_path)
    code_md_str = code_util.get_file_read(code_md_path)
    code_res = '\n'.join(code_util.call_py_file(code_path, python_path))
    data = {
        'code_str': code_str,
        'code_md_str': code_md_str,
        'name': name,
        'code_res': code_res
    }
    # every times view code,path config.count_view_code 's count +=1 (view code count log)
    utils.add_file_txt_count(config.count_view_code)
    return templates.TemplateResponse("code_view.html", {"request": request, "data": data, "message": name})


@router.put('/save')
async def save(item: Item):
    global code_name_map, code_map, code_name_list
    name = item.name
    # python code
    code_str = item.code_str
    # python code's Markdown note
    code_md_str = item.code_md_str
    # python code's path
    code_path = code_name_map[name][1]
    # python code's Markdown note 's path
    code_md_path = code_name_map[name][2]
    if code_str is not None:
        with open(code_path, 'w', encoding='utf-8') as of:
            of.write(code_str)
    if code_md_str is not None:
        with open(code_md_path, 'w', encoding='utf-8') as of:
            of.write(code_md_str)
    return {
        'status': 'success',
        'name': name
    }


@router.get('/addview')
async def index(request: Request):
    return templates.TemplateResponse("add_file.html", {"request": request, "message": 'Easy Leetcode'})


@router.put('/delete')
async def delete(item: Item):
    global code_name_map, code_map, code_name_list
    name = None
    try:
        name = item.name
        # python code's path
        code_path = code_name_map[name][1]
        # python code's Markdown note 's path
        code_md_path = code_name_map[name][2]
        remove_name(name)
        utils.del_file(code_path)
        utils.del_file(code_md_path)
        return {
            'status': 'success',
            'name': name
        }
    except Exception as e:
        print(e)
    return {
        'status': 'error',
        'name': name
    }


@router.put('/add')
async def add_file(item: Item):
    global code_name_map, code_map, code_name_list
    name = item.name
    # python code
    code_str = item.code_str
    # python code's Markdown note
    code_md_str = item.code_md_str
    if name not in code_name_map:
        code_path = os.path.join(code_map[-1][1], name + '.py')
        code_md_path = os.path.join(code_map[-1][2], name + '.md')
    else:
        return {
            'status': 'error:file exist !',
            'name': name
        }

    if code_str is None:
        code_str = "print('" + name + "')"
    if code_str is not None:
        with open(code_path, 'w', encoding='utf-8') as of:
            of.write(code_str)
    if code_md_str is None:
        code_md_str = "# " + name
    if code_md_str is not None:
        with open(code_md_path, 'w', encoding='utf-8') as of:
            of.write(code_md_str)
    try:
        idx = int(name.split('_')[1])
        title = name[2:].replace('_', ' ')
    except:
        idx = len(code_name_map) + 1
        name = 'L_' + str(idx) + '_' + name
        title = name[2:].replace('_', ' ')
    code_map, code_name_map, code_name_list = utils.load_data()
    return {
        'status': 'success',
        'name': name
    }


@router.put('/run')
async def router_run(item: Item):
    global code_name_map, code_map, code_name_list
    name = item.name
    code_str = item.code_str
    # code's python path, to temp path
    code_path = code_name_map[name][1].replace('.py', '_temp.py')
    with open(code_path, 'w', encoding='utf-8') as of:
        of.write(code_str)
    code_res = '\n'.join(code_util.call_py_file(code_path, python_path))
    # rm temp path
    os.remove(code_path)

    return {
        'status': 'success',
        'code_res': code_res,
        'name': name
    }


@router.get('/md/{name}')
async def view_md(request: Request, name: str = '001_Two_Sum'):
    global code_name_map, code_map, code_name_list
    if name not in code_name_map:
        return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Leetcode'})
    # 代码markdwon路径
    code_md_path = code_name_map[name][2]
    code_md_str = code_util.get_file_read(code_md_path)
    data = {
        'code_md_str': code_md_str,
        'name': name,
    }
    return templates.TemplateResponse("md.html", {"request": request, "data": data, "message": name})

==> easyleetcode-1.9.4.tar.gz: easyleetcode-1.9.4/easyleetcode/web/server.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : server.py
import os
from fastapi import APIRouter

from fastapi import Request
from easyleetcode.config import templates
import easyleetcode.web.code_util as code_util
from easyleetcode.web.Items import Item
import easyleetcode.web.utils as utils
import easyleetcode.config as config

router = APIRouter()

python_path = 'python '


@router.get('/')
async def index(request: Request):
    return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Leetcode'})


@router.get('/help')
async def help(request: Request):
    return templates.TemplateResponse("help.html", {"request": request, "message": 'Easy Leetcode'})


@router.get('/about')
async def about(request: Request):
    return templates.TemplateResponse("about.html", {"request": request, "message": 'Easy Leetcode'})


code_name_map, code_name_list = utils.load_data()


def remove_name(name):
    global code_name_map, code_name_list
    del code_name_map[name]

    ci = None
    for ci in code_name_list:
        if ci[0] == name:
            break
    if ci is not None:
        code_name_list.remove(ci)


@router.get('/view')
async def view(request: Request):
    count_day = utils.get_file_txt_count(config.count_day)
    count_view_code = utils.get_file_txt_count(config.count_view_code)
    data = {
        'all_num': len(code_name_list),
        'count_day': count_day,
        'count_view_code': count_view_code,
        'code_name_list': code_name_list
    }
    return templates.TemplateResponse("code_list.html", {"request": request, "data": data, "message": "Leetcode List"})


@router.get('/filter_view/{keyword}')
async def view(request: Request, keyword: str = 'L'):
    count_day = utils.get_file_txt_count(config.count_day)
    count_view_code = utils.get_file_txt_count(config.count_view_code)
    f_code_name_list = [ni for ni in code_name_list if keyword in ni[1]]
    data = {
        'all_num': len(code_name_list),
        'count_day': count_day,
        'count_view_code': count_view_code,
        'code_name_list': f_code_name_list
    }
    return templates.TemplateResponse("code_list.html", {"request": request, "data": data, "message": "Leetcode List"})


@router.get('/code/{name}')
async def view_code(request: Request, name: str = '001_Two_Sum'):
    global code_name_map
    if name not in code_name_map:
        return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Leetcode'})
    # 代码路径
    code_path = code_name_map[name][1]
    # 代码markdwon路径
    code_md_path = code_name_map[name][2]
    code_str = code_util.get_file_read(code_path)
    code_md_str = code_util.get_file_read(code_md_path)
    code_res = '\n'.join(code_util.call_py_file(code_path, python_path))
    data = {
        'code_str': code_str,
        'code_md_str': code_md_str,
        'name': name,
        'code_res': code_res
    }
    # every times view code,path config.count_view_code 's count +=1 (view code count log)
    utils.add_file_txt_count(config.count_view_code)
    return templates.TemplateResponse("code_view.html", {"request": request, "data": data, "message": name})


@router.put('/save')
async def save(item: Item):
    global code_name_map
    name = item.name
    # python code
    code_str = item.code_str
    # python code's Markdown note
    code_md_str = item.code_md_str
    # python code's path
    code_path = code_name_map[name][1]
    # python code's Markdown note 's path
    code_md_path = code_name_map[name][2]
    if code_str is not None:
        with open(code_path, 'w', encoding='utf-8') as of:
            of.write(code_str)
    if code_md_str is not None:
        with open(code_md_path, 'w', encoding='utf-8') as of:
            of.write(code_md_str)
    return {
        'status': 'success',
        'name': name
    }


@router.get('/addview')
async def index(request: Request):
    return templates.TemplateResponse("add_file.html", {"request": request, "message": 'Easy Leetcode'})


@router.put('/delete')
async def delete(item: Item):
    global code_name_map
    name = None
    try:
        name = item.name
        # python code's path
        code_path = code_name_map[name][1]
        # python code's Markdown note 's path
        code_md_path = code_name_map[name][2]
        remove_name(name)
        utils.del_file(code_path)
        utils.del_file(code_md_path)
        return {
            'status': 'success',
            'name': name
        }
    except Exception as e:
        print(e)
    return {
        'status': 'error',
        'name': name
    }


@router.put('/add')
async def add_file(item: Item):
    global code_name_map, code_name_list
    name = item.name
    code_str = item.code_str
    code_md_str = item.code_md_str
    if name not in code_name_map:
        code_path = os.path.join(code_name_map['root'][1], name + '.py')
        code_md_path = os.path.join(code_name_map['root'][2], name + '.md')
    else:
        return {
            'status': 'error:file exist !',
            'name': name
        }

    if code_str is None:
        code_str = "print('" + name + "')"
    if code_str is not None:
        with open(code_path, 'w', encoding='utf-8') as of:
            of.write(code_str)
    if code_md_str is None:
        code_md_str = "# " + name
    if code_md_str is not None:
        with open(code_md_path, 'w', encoding='utf-8') as of:
            of.write(code_md_str)

    code_name_map, code_name_list = utils.load_data()
    return {
        'status': 'success',
        'name': name
    }


@router.put('/run')
async def router_run(item: Item):
    global code_name_map
    name = item.name
    code_str = item.code_str
    # code's python path, to temp path
    code_path = code_name_map[name][1].replace('.py', '_temp.py')
    with open(code_path, 'w', encoding='utf-8') as of:
        of.write(code_str)
    code_res = '\n'.join(code_util.call_py_file(code_path, python_path))
    # rm temp path
    os.remove(code_path)

    return {
        'status': 'success',
        'code_res': code_res,
        'name': name
    }


@router.get('/md/{name}')
async def view_md(request: Request, name: str = '001_Two_Sum'):
    global code_name_map
    if name not in code_name_map:
        return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Leetcode'})
    # 代码markdwon路径
    code_md_path = code_name_map[name][2]
    code_md_str = code_util.get_file_read(code_md_path)
    data = {
        'code_md_str': code_md_str,
        'name': name,
    }
    return templates.TemplateResponse("md.html", {"request": request, "data": data, "message": name})
